#! /usr/bin/env node
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const program = require("commander");
const path = require("path");
const winston = require("winston");
const _1 = require("./");
const utils_1 = require("./utils");
function runCli() {
    return __awaiter(this, void 0, void 0, function* () {
        const p = program
            .version("0.1.2")
            .option("-d, --debug", "Emits debug messages");
        p.command("unpack <path>")
            .description("Will remove all traces of packing tool at the specified "
            + "path or the current directory if none is specified")
            .option("-o, --output <path>", "Path for output directory")
            .action(unpack);
        p.command("pack <path>")
            .description("Will pack the specified path or the current directory if none is specified")
            .option("-u, --uglify", "Uglify the project when webpacking")
            .option("-o, --output <path>", "Path for output directory")
            .action(pack);
        p.command("*", null, { noHelp: true, isDefault: true })
            .action(() => {
            p.help();
        });
        p.parse(process.argv);
        if (!process.argv.slice(2).length) {
            p.help();
        }
    });
}
function unpack(name, options) {
    return __awaiter(this, void 0, void 0, function* () {
        if (options.debug) {
            process.env.DEBUG = "*";
        }
        let projectRootPath = "";
        try {
            projectRootPath = name ?
                path.resolve(process.cwd(), name) : process.cwd();
        }
        catch (error) {
            winston.error(error);
            throw new Error("Could not determine route");
        }
        let outputPath = ".funcpack";
        try {
            if (options.path) {
                outputPath = program.opts().path;
            }
        }
        catch (e) {
            winston.error(e);
            throw new Error("Could not parse the uglify option");
        }
        winston.info("Unpacking project at: " + projectRootPath);
        yield _1.Unpacker.unpack({ projectRootPath, outputPath });
        winston.info("Complete!");
    });
}
function pack(name, options) {
    return __awaiter(this, void 0, void 0, function* () {
        const config = yield utils_1.ConfigLoader.loadConfig();
        if (options.debug) {
            process.env.DEBUG = "*";
        }
        let projectRootPath = "";
        try {
            projectRootPath = name ?
                path.join(process.cwd(), name) : process.cwd();
        }
        catch (error) {
            winston.error(error);
            throw new Error("Could not determine route");
        }
        let uglify = false;
        try {
            if (options.uglify) {
                uglify = true;
            }
        }
        catch (e) {
            winston.error(e);
            throw new Error("Could not parse the uglify option");
        }
        let outputPath = ".funcpack";
        try {
            if (options.path) {
                outputPath = program.opts().path;
            }
        }
        catch (e) {
            winston.error(e);
            throw new Error("Could not parse the uglify option");
        }
        const generator = new _1.PackhostGenerator({
            projectRootPath,
        });
        try {
            winston.info("Generating project files/metadata");
            yield generator.updateProject();
        }
        catch (error) {
            winston.error(error);
            throw new Error("Could not generate project");
        }
        try {
            winston.info("Webpacking project");
            yield _1.WebpackRunner.run({
                projectRootPath,
                uglify,
                outputPath,
                ignoredModules: config.ignoredModules,
            });
        }
        catch (error) {
            winston.error(error);
            throw new Error("Could not webpack project");
        }
        winston.info("Complete!");
        process.exit(0);
    });
}
runCli();
//# sourceMappingURL=main.js.map