"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const debugLib = require("debug");
const path = require("path");
const utils_1 = require("./utils");
const debug = debugLib("azure-functions-pack:Unpack");
class Unpacker {
    static unpack(options) {
        return __awaiter(this, void 0, void 0, function* () {
            return new Promise((resolve, reject) => __awaiter(this, void 0, void 0, function* () {
                try {
                    if (utils_1.FileHelper.exists(path.resolve(options.projectRootPath, options.outputPath))) {
                        debug(`Removing funckpack output: ${options.outputPath}`);
                        yield utils_1.FileHelper.rimraf(path.resolve(options.projectRootPath, options.outputPath));
                    }
                    else {
                        debug(`Did not find funckpack output: ${options.outputPath}`);
                    }
                    debug(`Finding Functions`);
                    const functionDirectories = (yield utils_1.FileHelper.readdir(options.projectRootPath));
                    debug(`Found Functions: ${functionDirectories.join(", ")}`);
                    for (const name of functionDirectories) {
                        if (!(yield utils_1.FileHelper.stat(path.resolve(options.projectRootPath, name))).isDirectory()) {
                            continue;
                        }
                        if (!(yield utils_1.FileHelper.exists(path.resolve(options.projectRootPath, name, "function.json")))) {
                            continue;
                        }
                        const fxJsonPath = path.resolve(options.projectRootPath, name, "function.json");
                        const fxJson = yield utils_1.FileHelper.readFileAsJSON(fxJsonPath);
                        if (fxJson._originalScriptFile) {
                            debug(`Removing _originalScriptFile from ${name}'s function.json`);
                            fxJson.scriptFile = fxJson._originalScriptFile + "";
                            delete fxJson._originalScriptFile;
                        }
                        if (fxJson._originalEntryPoint || fxJson._originalEntryPoint === false) {
                            debug(`Removing _originalEntryPoint from ${name}'s function.json`);
                            fxJson.entryPoint = fxJson._originalEntryPoint;
                            if (fxJson._originalEntryPoint === false) {
                                delete fxJson.entryPoint;
                            }
                            else {
                                fxJson.entryPoint = fxJson._originalEntryPoint;
                            }
                            delete fxJson._originalEntryPoint;
                        }
                        debug(`Overwriting ${name}'s function.json`);
                        yield utils_1.FileHelper.overwriteFileUtf8(fxJsonPath, JSON.stringify(fxJson, null, " "));
                        resolve();
                    }
                }
                catch (e) {
                    debug(e);
                    reject(e);
                }
            }));
        });
    }
}
exports.Unpacker = Unpacker;
//# sourceMappingURL=unpack.js.map