"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const rimraf = require("rimraf");
class FileHelper {
    static readdir(path) {
        return new Promise((resolve, reject) => {
            fs.readdir(path, (err, files) => {
                if (err) {
                    return reject(err);
                }
                resolve(files);
            });
        });
    }
    static stat(path) {
        return new Promise((resolve, reject) => {
            fs.stat(path, (err, stat) => {
                if (err) {
                    return reject(err);
                }
                resolve(stat);
            });
        });
    }
    static readFileUtf8(path) {
        return new Promise((resolve, reject) => {
            fs.readFile(path, "utf8", (err, content) => {
                if (err) {
                    return reject(err);
                }
                resolve(content);
            });
        });
    }
    static exists(path) {
        return new Promise((resolve, reject) => {
            fs.access(path, (err) => {
                resolve(!err);
            });
        });
    }
    static readFileAsJSON(path) {
        return new Promise((resolve, reject) => __awaiter(this, void 0, void 0, function* () {
            try {
                const content = yield FileHelper.readFileUtf8(path);
                resolve(JSON.parse(content));
            }
            catch (err) {
                reject(err);
            }
        }));
    }
    static overwriteFileUtf8(path, content) {
        return new Promise((resolve, reject) => {
            fs.truncate(path, (err) => __awaiter(this, void 0, void 0, function* () {
                if (err) {
                    return reject(err);
                }
                yield this.writeFileUtf8(path, content).catch(reject).then(resolve, reject);
            }));
        });
    }
    static writeFileUtf8(path, content) {
        return new Promise((resolve, reject) => {
            fs.writeFile(path, content, (err) => {
                if (err) {
                    return reject(err);
                }
                resolve();
            });
        });
    }
    static mkdir(path) {
        return new Promise((resolve, reject) => {
            fs.mkdir(path, (err) => {
                if (err) {
                    return reject(err);
                }
                resolve();
            });
        });
    }
    static rimraf(path) {
        return new Promise((resolve, reject) => {
            rimraf(path, (err) => {
                if (err) {
                    return reject(err);
                }
                resolve();
            });
        });
    }
    static rename(pathOld, pathNew) {
        return new Promise((resolve, reject) => {
            fs.rename(pathOld, pathNew, (err) => {
                if (err) {
                    return reject(err);
                }
                resolve();
            });
        });
    }
}
exports.FileHelper = FileHelper;
//# sourceMappingURL=fs-helper.js.map