"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const debugLib = require("debug");
const path = require("path");
const webpack = require("webpack");
const utils_1 = require("./utils");
const debug = debugLib("azure-functions-pack:WebpackRunner");
class WebpackRunner {
    static run(options) {
        options.indexFileName = options.indexFileName || "index.js";
        options.outputPath = options.outputPath || ".funcpack";
        options.uglify = options.uglify || false;
        options.ignoredModules = options.ignoredModules || [];
        return new Promise((resolve, reject) => __awaiter(this, void 0, void 0, function* () {
            debug("Setting up paths");
            const oldPath = path.join(options.projectRootPath, options.outputPath, options.indexFileName);
            const newPath = path.join(options.projectRootPath, options.outputPath, "original." + options.indexFileName);
            const outputPath = path.join(options.projectRootPath, options.outputPath, "output.js");
            const ignoredModules = {};
            for (const mod of options.ignoredModules) {
                ignoredModules[mod.toLowerCase()] = mod;
            }
            debug("Creating Webpack Configuration");
            const config = {
                entry: oldPath,
                externals: ignoredModules,
                node: {
                    __dirname: false,
                    __filename: false,
                },
                output: {
                    filename: "output.js",
                    library: "index",
                    libraryTarget: "commonjs2",
                    path: path.join(options.projectRootPath, options.outputPath),
                },
                plugins: [],
                target: "node",
            };
            if (options.uglify) {
                debug("Adding uglify plugin");
                try {
                    config.plugins.push(new webpack.optimize.UglifyJsPlugin());
                }
                catch (e) {
                    debug(e);
                }
            }
            debug("Creating Webpack instance");
            const compiler = webpack(config);
            debug("Started webpack");
            compiler.run((err, stats) => __awaiter(this, void 0, void 0, function* () {
                debug("Webpack finished");
                if (err || stats.hasErrors()) {
                    return reject(err || stats.toString({ errors: true }));
                }
                debug("\n" + stats.toString());
                debug("Saving the original the entry file: %s -> %s", oldPath, newPath);
                if (yield utils_1.FileHelper.exists(newPath)) {
                    yield utils_1.FileHelper.rimraf(newPath);
                }
                yield utils_1.FileHelper.rename(oldPath, newPath);
                debug("Renaming the output file");
                yield utils_1.FileHelper.rename(outputPath, oldPath);
                resolve();
            }));
        }));
    }
}
exports.WebpackRunner = WebpackRunner;
//# sourceMappingURL=webpack-runner.js.map